Installation
============


Installing emiproc can be done as a standard python package.

First create a folder for emiproc and go into it 

.. code::

    mkdir emiproc 
    cd emiproc


Clone the repository::

    git clone https://github.com/C2SM-RCM/emiproc.git .


Then install using pip.
Installing as an editable (`-e` options) allows you to directly modify 
the cloned code.

.. code::

    pip install -e .




